==> cosmoai-0.9.1.10-py3-none-any.whl: cosmo/terminal_interface/validate_llm_settings.py <==
import getpass
import os
import time

import litellm

from ..utils.display_markdown_message import display_markdown_message


def validate_llm_settings(cosmo):
    """
    Interactivley prompt the user for required LLM settings
    """

    # This runs in a while loop so `continue` lets us start from the top
    # after changing settings (like switching to/from local)
    while True:
        if cosmo.local:
            # We have already displayed a message.
            # (This strange behavior makes me think validate_llm_settings needs to be rethought / refactored)
            break

        else:
            # Ensure API keys are set as environment variables

            # OpenAI
            if cosmo.model in litellm.open_ai_chat_completion_models:
                if not os.environ.get("OPENAI_API_KEY") and not cosmo.api_key:
                    display_welcome_message_once()

                    display_markdown_message(
                        """---
                    > OpenAI API key not found

                    To use `GPT-4` (highly recommended) please provide an OpenAI API key.

                    To use another language model, consult the documentation at [docs.opencosmo.com](https://docs.opencosmo.com/language-model-setup/).
                    
                    ---
                    """
                    )

                    response = getpass.getpass("OpenAI API key: ")
                    print(f"OpenAI API key: {response[:4]}...{response[-4:]}")

                    display_markdown_message(
                        """

                    **Tip:** To save this key for later, run `export OPENAI_API_KEY=your_api_key` on Mac/Linux or `setx OPENAI_API_KEY your_api_key` on Windows.
                    
                    ---"""
                    )

                    cosmo.api_key = response
                    time.sleep(2)
                    break

            # This is a model we don't have checks for yet.
            break

    # If we're here, we passed all the checks.

    # Auto-run is for fast, light useage -- no messages.
    # If local, we've already displayed a message.
    if not cosmo.auto_run and not cosmo.local:
        display_markdown_message(f"> Model set to `{cosmo.model}`")
    return


def display_welcome_message_once():
    """
    Displays a welcome message only on its first call.

    (Uses an internal attribute `_displayed` to track its state.)
    """
    if not hasattr(display_welcome_message_once, "_displayed"):
        display_markdown_message(
            """
        ●

        Welcome to **Cosmo AI**.

        We're glad to have you here. Cosmo AI is a powerful tool designed to help you with you just anything you want!

        If you need any assistance, please refer to our documentation at [docs.opencosmo.com](https://docs.cosmoai.net/). 

        Happy Coding!
        """
        )
        time.sleep(1.5)

        display_welcome_message_once._displayed = True

==> cosmoai-0.9.1.11-py3-none-any.whl: cosmo/terminal_interface/validate_llm_settings.py <==
import getpass
import os
import time

import litellm

from ..utils.display_markdown_message import display_markdown_message


def validate_llm_settings(cosmo):
    """
    Interactivley prompt the user for required LLM settings
    """

    # This runs in a while loop so `continue` lets us start from the top
    # after changing settings (like switching to/from local)
    while True:
        if cosmo.local:
            # We have already displayed a message.
            # (This strange behavior makes me think validate_llm_settings needs to be rethought / refactored)
            break

        else:
            # Ensure API keys are set as environment variables

            # OpenAI
            if cosmo.model in litellm.open_ai_chat_completion_models:
                if not os.environ.get("OPENAI_API_KEY") and not cosmo.api_key:
                    display_welcome_message_once()

                    display_markdown_message(
                        """---
                    > OpenAI API key not found

                    To use `GPT-4` (highly recommended) please provide an OpenAI API key.

                    To use another language model, Please refer to our documentation at [docs.cosmoai.net](https://docs.cosmoai.net/language-model-setup/).
                    
                    ---
                    """
                    )

                    response = getpass.getpass("OpenAI API key: ")
                    print(f"OpenAI API key: {response[:4]}...{response[-4:]}")

                    display_markdown_message(
                        """

                    **Tip:** To save this key for later, run `export OPENAI_API_KEY=your_api_key` on Mac/Linux or `setx OPENAI_API_KEY your_api_key` on Windows.
                    
                    ---"""
                    )

                    cosmo.api_key = response
                    time.sleep(2)
                    break

            # This is a model we don't have checks for yet.
            break

    # If we're here, we passed all the checks.

    # Auto-run is for fast, light useage -- no messages.
    # If local, we've already displayed a message.
    if not cosmo.auto_run and not cosmo.local:
        display_markdown_message(f"> Model set to `{cosmo.model}`")
    return


def display_welcome_message_once():
    """
    Displays a welcome message only on its first call.

    (Uses an internal attribute `_displayed` to track its state.)
    """
    if not hasattr(display_welcome_message_once, "_displayed"):
        display_markdown_message(
            """
        ●

        Welcome to **Cosmo AI**.

        We're glad to have you here. Cosmo AI is a powerful tool designed to help you with you just anything you want!

        If you need any assistance, please refer to our documentation at [docs.cosmoai.net](https://docs.cosmoai.net/). 

        Happy Coding!
        """
        )
        time.sleep(1.5)

        display_welcome_message_once._displayed = True
